@@ -164,7 +164,7 @@ class SMTModule extends SMTServiceHelper
     	//module found in MOD1 or MOD2 or MOD3
     	$difference = ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD1 ) ) != SMTOtuApi::RES_OK );
     	$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD2 ) ) != SMTOtuApi::RES_OK );
-    	if ( (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2()) && !SMTOtuMode::isONMS() && !SMTOtuMode::isROTAU() && !SMTOtuMode::isUFOM() )
+    	if ( (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2()) && !SMTOtuMode::isONMS() && !SMTOtuMode::isROTAU() && !SMTOtuMode::isUFOM() )
     	{
     		$difference |= ( $this->sendReceive( sprintf( SMTOtuApi::CMD_check_MOD, SMTModuleDto::MOD3 ) ) != SMTOtuApi::RES_OK );
     	}
@@ -186,7 +186,7 @@ class SMTModule extends SMTServiceHelper
         $index = 0;
         $hasModuleDifference = FALSE;
         //no MOD3 on compactOTU and in ONMS mode
-        $moduleCount = (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2() || SMTOtuType::isMts8KV2())&&( !SMTOtuMode::isONMS() )? self::MODULE_COUNT : self::MODULE_COUNT - 1;
+        $moduleCount = (SMTOtuType::isOTH() || SMTOtuType::isOtu8KV2())&&( !SMTOtuMode::isONMS() )? self::MODULE_COUNT : self::MODULE_COUNT - 1;
         
         while ( $index < $moduleCount )
         {
