@@ -54,7 +54,7 @@ class MyFileObj(io.FileIO):
         percent = int(self.tell() * 100 / self.__fsize)
         if percent != self.lastpercent:
             if self.__cls is not None:
-                self.__cls.expose("Upgrade", 50 + (percent * 0.4), self.__rname, "Installation", percent)
+                self.__cls.expose("Upgrade", int(50 + (percent * 0.4)), self.__rname, "Installation", int(percent))
             self.lastpercent = percent
         return io.FileIO.read(self, size)
 
@@ -165,7 +165,7 @@ def start_upgrade_tar(xmlrelease, hook=None, options={}, smartmanager=None):
         if int(percent) != int(chunk_report.lastpercent):
             if smartmanager is not None:
                 # Dowload during 0%~45% of total
-                smartmanager.expose("Upgrade", percent * 0.45, name, "Download release", percent)
+                smartmanager.expose("Upgrade", int(percent * 0.45), name, "Download release", int(percent))
             chunk_report.lastpercent = percent
 
     chunk_report.lastpercent = 1000
