@@ -1428,7 +1428,7 @@ def t_tacb_is_ready(cmd):
         print_error("# Command must be: t_tacb_is_ready")
 
     p = subprocess.Popen(
-        "systemctl is-active osb-init", shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
+        "systemctl is-active init-otdr-modules", shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT, close_fds=True)
     p.wait()
     err = p.returncode
